package com.zehong.web.controller.system;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TFlowmeter;
import com.zehong.system.service.ITFlowmeterService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 流量计Controller
 * 
 * @author zehong
 * @date 2021-07-08
 */
@RestController
@RequestMapping("/system/flowmeter")
public class TFlowmeterController extends BaseController
{
    @Autowired
    private ITFlowmeterService tFlowmeterService;

    /**
     * 查询流量计列表
     */
    @PreAuthorize("@ss.hasPermi('system:flowmeter:list')")
    @GetMapping("/list")
    public TableDataInfo list(TFlowmeter tFlowmeter)
    {
        startPage();
        List<TFlowmeter> list = tFlowmeterService.selectTFlowmeterList(tFlowmeter);
        return getDataTable(list);
    }

    /**
     * 导出流量计列表
     */
    @PreAuthorize("@ss.hasPermi('system:flowmeter:export')")
    @Log(title = "流量计", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TFlowmeter tFlowmeter)
    {
        List<TFlowmeter> list = tFlowmeterService.selectTFlowmeterList(tFlowmeter);
        ExcelUtil<TFlowmeter> util = new ExcelUtil<TFlowmeter>(TFlowmeter.class);
        return util.exportExcel(list, "流量计数据");
    }

    /**
     * 获取流量计详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:flowmeter:query')")
    @GetMapping(value = "/{flowmeterId}")
    public AjaxResult getInfo(@PathVariable("flowmeterId") Long flowmeterId)
    {
        return AjaxResult.success(tFlowmeterService.selectTFlowmeterById(flowmeterId));
    }

    /**
     * 新增流量计
     */
    @PreAuthorize("@ss.hasPermi('system:flowmeter:add')")
    @Log(title = "流量计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TFlowmeter tFlowmeter)
    {
        return toAjax(tFlowmeterService.insertTFlowmeter(tFlowmeter));
    }

    /**
     * 修改流量计
     */
    @PreAuthorize("@ss.hasPermi('system:flowmeter:edit')")
    @Log(title = "流量计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TFlowmeter tFlowmeter)
    {
        return toAjax(tFlowmeterService.updateTFlowmeter(tFlowmeter));
    }

    /**
     * 删除流量计
     */
    @PreAuthorize("@ss.hasPermi('system:flowmeter:remove')")
    @Log(title = "流量计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{flowmeterIds}")
    public AjaxResult remove(@PathVariable Long[] flowmeterIds)
    {
        return toAjax(tFlowmeterService.deleteTFlowmeterByIds(flowmeterIds));
    }
}
