package com.zehong.web.controller.system;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TGasMeter;
import com.zehong.system.service.ITGasMeterService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 物联网燃气表Controller
 * 
 * @author zehong
 * @date 2021-07-08
 */
@RestController
@RequestMapping("/system/gasMeter")
public class TGasMeterController extends BaseController
{
    @Autowired
    private ITGasMeterService tGasMeterService;

    /**
     * 查询物联网燃气表列表
     */
    @PreAuthorize("@ss.hasPermi('system:gasMeter:list')")
    @GetMapping("/list")
    public TableDataInfo list(TGasMeter tGasMeter)
    {
        startPage();
        List<TGasMeter> list = tGasMeterService.selectTGasMeterList(tGasMeter);
        return getDataTable(list);
    }

    /**
     * 导出物联网燃气表列表
     */
    @PreAuthorize("@ss.hasPermi('system:gasMeter:export')")
    @Log(title = "物联网燃气表", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TGasMeter tGasMeter)
    {
        List<TGasMeter> list = tGasMeterService.selectTGasMeterList(tGasMeter);
        ExcelUtil<TGasMeter> util = new ExcelUtil<TGasMeter>(TGasMeter.class);
        return util.exportExcel(list, "物联网燃气表数据");
    }

    /**
     * 获取物联网燃气表详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:gasMeter:query')")
    @GetMapping(value = "/{gasId}")
    public AjaxResult getInfo(@PathVariable("gasId") Long gasId)
    {
        return AjaxResult.success(tGasMeterService.selectTGasMeterById(gasId));
    }

    /**
     * 新增物联网燃气表
     */
    @PreAuthorize("@ss.hasPermi('system:gasMeter:add')")
    @Log(title = "物联网燃气表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TGasMeter tGasMeter)
    {
        return toAjax(tGasMeterService.insertTGasMeter(tGasMeter));
    }

    /**
     * 修改物联网燃气表
     */
    @PreAuthorize("@ss.hasPermi('system:gasMeter:edit')")
    @Log(title = "物联网燃气表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TGasMeter tGasMeter)
    {
        return toAjax(tGasMeterService.updateTGasMeter(tGasMeter));
    }

    /**
     * 删除物联网燃气表
     */
    @PreAuthorize("@ss.hasPermi('system:gasMeter:remove')")
    @Log(title = "物联网燃气表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{gasIds}")
    public AjaxResult remove(@PathVariable Long[] gasIds)
    {
        return toAjax(tGasMeterService.deleteTGasMeterByIds(gasIds));
    }
}
