package com.zehong.web.controller.system;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TPipe;
import com.zehong.system.service.ITPipeService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 管道信息Controller
 * 
 * @author zehong
 * @date 2021-07-08
 */
@RestController
@RequestMapping("/system/pipe")
public class TPipeController extends BaseController
{
    @Autowired
    private ITPipeService tPipeService;

    /**
     * 查询管道信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:pipe:list')")
    @GetMapping("/list")
    public TableDataInfo list(TPipe tPipe)
    {
        startPage();
        List<TPipe> list = tPipeService.selectTPipeList(tPipe);
        return getDataTable(list);
    }

    /**
     * 导出管道信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:pipe:export')")
    @Log(title = "管道信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TPipe tPipe)
    {
        List<TPipe> list = tPipeService.selectTPipeList(tPipe);
        ExcelUtil<TPipe> util = new ExcelUtil<TPipe>(TPipe.class);
        return util.exportExcel(list, "管道信息数据");
    }

    /**
     * 获取管道信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:pipe:query')")
    @GetMapping(value = "/{pipeId}")
    public AjaxResult getInfo(@PathVariable("pipeId") Long pipeId)
    {
        return AjaxResult.success(tPipeService.selectTPipeById(pipeId));
    }

    /**
     * 新增管道信息
     */
    @PreAuthorize("@ss.hasPermi('system:pipe:add')")
    @Log(title = "管道信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TPipe tPipe)
    {
        return toAjax(tPipeService.insertTPipe(tPipe));
    }

    /**
     * 修改管道信息
     */
    @PreAuthorize("@ss.hasPermi('system:pipe:edit')")
    @Log(title = "管道信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TPipe tPipe)
    {
        return toAjax(tPipeService.updateTPipe(tPipe));
    }

    /**
     * 删除管道信息
     */
    @PreAuthorize("@ss.hasPermi('system:pipe:remove')")
    @Log(title = "管道信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{pipeIds}")
    public AjaxResult remove(@PathVariable Long[] pipeIds)
    {
        return toAjax(tPipeService.deleteTPipeByIds(pipeIds));
    }
}
