package com.zehong.web.controller.system;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TRegulatorBox;
import com.zehong.system.service.ITRegulatorBoxService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 调压箱Controller
 * 
 * @author zehong
 * @date 2021-07-08
 */
@RestController
@RequestMapping("/system/regulatorBox")
public class TRegulatorBoxController extends BaseController
{
    @Autowired
    private ITRegulatorBoxService tRegulatorBoxService;

    /**
     * 查询调压箱列表
     */
    @PreAuthorize("@ss.hasPermi('system:regulatorBox:list')")
    @GetMapping("/list")
    public TableDataInfo list(TRegulatorBox tRegulatorBox)
    {
        startPage();
        List<TRegulatorBox> list = tRegulatorBoxService.selectTRegulatorBoxList(tRegulatorBox);
        return getDataTable(list);
    }

    /**
     * 导出调压箱列表
     */
    @PreAuthorize("@ss.hasPermi('system:regulatorBox:export')")
    @Log(title = "调压箱", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TRegulatorBox tRegulatorBox)
    {
        List<TRegulatorBox> list = tRegulatorBoxService.selectTRegulatorBoxList(tRegulatorBox);
        ExcelUtil<TRegulatorBox> util = new ExcelUtil<TRegulatorBox>(TRegulatorBox.class);
        return util.exportExcel(list, "调压箱数据");
    }

    /**
     * 获取调压箱详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:regulatorBox:query')")
    @GetMapping(value = "/{boxId}")
    public AjaxResult getInfo(@PathVariable("boxId") Long boxId)
    {
        return AjaxResult.success(tRegulatorBoxService.selectTRegulatorBoxById(boxId));
    }

    /**
     * 新增调压箱
     */
    @PreAuthorize("@ss.hasPermi('system:regulatorBox:add')")
    @Log(title = "调压箱", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TRegulatorBox tRegulatorBox)
    {
        return toAjax(tRegulatorBoxService.insertTRegulatorBox(tRegulatorBox));
    }

    /**
     * 修改调压箱
     */
    @PreAuthorize("@ss.hasPermi('system:regulatorBox:edit')")
    @Log(title = "调压箱", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TRegulatorBox tRegulatorBox)
    {
        return toAjax(tRegulatorBoxService.updateTRegulatorBox(tRegulatorBox));
    }

    /**
     * 删除调压箱
     */
    @PreAuthorize("@ss.hasPermi('system:regulatorBox:remove')")
    @Log(title = "调压箱", businessType = BusinessType.DELETE)
	@DeleteMapping("/{boxIds}")
    public AjaxResult remove(@PathVariable Long[] boxIds)
    {
        return toAjax(tRegulatorBoxService.deleteTRegulatorBoxByIds(boxIds));
    }
}
