package com.zehong.web.controller.system;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TValveWell;
import com.zehong.system.service.ITValveWellService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 阀门井Controller
 * 
 * @author zehong
 * @date 2021-07-08
 */
@RestController
@RequestMapping("/system/valveWell")
public class TValveWellController extends BaseController
{
    @Autowired
    private ITValveWellService tValveWellService;

    /**
     * 查询阀门井列表
     */
    @PreAuthorize("@ss.hasPermi('system:valveWell:list')")
    @GetMapping("/list")
    public TableDataInfo list(TValveWell tValveWell)
    {
        startPage();
        List<TValveWell> list = tValveWellService.selectTValveWellList(tValveWell);
        return getDataTable(list);
    }

    /**
     * 导出阀门井列表
     */
    @PreAuthorize("@ss.hasPermi('system:valveWell:export')")
    @Log(title = "阀门井", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TValveWell tValveWell)
    {
        List<TValveWell> list = tValveWellService.selectTValveWellList(tValveWell);
        ExcelUtil<TValveWell> util = new ExcelUtil<TValveWell>(TValveWell.class);
        return util.exportExcel(list, "阀门井数据");
    }

    /**
     * 获取阀门井详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:valveWell:query')")
    @GetMapping(value = "/{wellId}")
    public AjaxResult getInfo(@PathVariable("wellId") Long wellId)
    {
        return AjaxResult.success(tValveWellService.selectTValveWellById(wellId));
    }

    /**
     * 新增阀门井
     */
    @PreAuthorize("@ss.hasPermi('system:valveWell:add')")
    @Log(title = "阀门井", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TValveWell tValveWell)
    {
        return toAjax(tValveWellService.insertTValveWell(tValveWell));
    }

    /**
     * 修改阀门井
     */
    @PreAuthorize("@ss.hasPermi('system:valveWell:edit')")
    @Log(title = "阀门井", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TValveWell tValveWell)
    {
        return toAjax(tValveWellService.updateTValveWell(tValveWell));
    }

    /**
     * 删除阀门井
     */
    @PreAuthorize("@ss.hasPermi('system:valveWell:remove')")
    @Log(title = "阀门井", businessType = BusinessType.DELETE)
	@DeleteMapping("/{wellIds}")
    public AjaxResult remove(@PathVariable Long[] wellIds)
    {
        return toAjax(tValveWellService.deleteTValveWellByIds(wellIds));
    }
}
